@@ -3,7 +3,7 @@
 topSrcDir="$PWD"
 
 if [ ! -d "debian" ]
-then 
+then
     echo "Not located in the top source directory."
     exit 1
 fi
@@ -29,6 +29,3 @@ do
     fi
 
 done
-
-# Finally add the pdf file itself:
-echo "debian/python-pymzml-doc/usr/share/doc/python3-pymzml/pymzML.pdf" >> ${topSrcDir}/debian/source/include-binaries
